pub fn get_config_path() -> Result<String, Box<dyn Error>>Expand description
Returns the user’s configuration directory.
On Unix systems, this is determined by the XDG_CONFIG_HOME environment variable or defaults
to $HOME/.config. On Windows, it uses LOCALAPPDATA.
Errors
Returns an error if the configuration directory cannot be determined.